/*******************************************************************************
* File Name: main.c
*
* Version: 2.0
*
* Description:
*  This project displays "BootloadableTest" message on the LCD after successful 
*  loading.
*  To test bootloader:
*   1. Build the USBFS_Bootloader project. Add the USBFS_Bootloadable 
*      Example Project to current workspace. Add dependency of the bootloadable 
*      project to the latest bootloader hex file. Build USBFS_Bootloadable 
*      project and program the Bootloader hex file on to the target device.
*   2. Connect USB cable from the computer to the CY8CKIT-001.
*   3. Select 3.3V in SW3 and plug-in power to the CY8CKIT-001
*   4. Run Bootloader Host Tool from PSoC Creator/Tools menu.
*   5. Select USB Human Interface Device[04B4_B71D] in Ports window. 
*   6. Open Bootloadable.cyacd file and press Program button.
*   7. Observe correct message on LCD: "BootloadableTest".   
*
********************************************************************************
* Copyright 2012, Cypress Semiconductor Corporation. All rights reserved.
* This software is owned by Cypress Semiconductor Corporation and is protected
* by and subject to worldwide patent and copyright laws and treaties.
* Therefore, you may use this software only as provided in the license agreement
* accompanying the software package from which you obtained this software.
* CYPRESS AND ITS SUPPLIERS MAKE NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
* WITH REGARD TO THIS SOFTWARE, INCLUDING, BUT NOT LIMITED TO, NONINFRINGEMENT,
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
*******************************************************************************/

#include <device.h>



#define TX_LED_BLINK_ON_MS 40
#define TX_LED_BLINK_OFF_MS 50
    
// Status register bits
#define STATUS_KEY_0  0x01
#define STATUS_KEY_1  0x02
#define STATUS_BOOT   0x04
#define STATUS_BEAT   0x08
#define STATUS_ATU_0  0x10
#define STATUS_IAMBIC_CLOCK 0x20

// Control register bits
#define CONTROL_LED      0x01
#define CONTROL_RX       0x02
#define CONTROL_TX       0x04
#define CONTROL_AMP      0x08
#define CONTROL_XK       0x10
#define CONTROL_ATU_0    0x20
#define CONTROL_ATU_0_OE 0x40
#define CONTROL_ATU_1    0x80


int main()
{
    uint16 blink, blink_i;
    uint16 blink_time = 1000;
    
    /* Place your initialization/startup code here (e.g. MyInst_Start()) */

    CyGlobalIntEnable;  /* Uncomment this line to enable global interrupts. */
    for(;;)
    {
        
        
        blink--;
        if (!blink) {
            blink_i = Control_Read();
            if (blink_i & CONTROL_LED) blink = TX_LED_BLINK_OFF_MS * blink_time;
                else blink = TX_LED_BLINK_ON_MS * blink_time;
            Control_Write(blink_i ^ CONTROL_LED);
        }
  
        
        
        /* Place your application code here. */
    }
}


/* [] END OF FILE */
